pub fn read_wrapped_data<T: ReadableType>(
reader: &mut impl Read,
) -> IgniteResult<Option<T>>Expand description
Reads data objects that are wrapped in the WrappedData(type code = 27)
pub fn read_wrapped_data<T: ReadableType>(
reader: &mut impl Read,
) -> IgniteResult<Option<T>>Reads data objects that are wrapped in the WrappedData(type code = 27)